/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2011-2019 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "baseIOdictionary.H"
#include "objectRegistry.H"
#include "Pstream.H"
#include "Time.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
    defineTypeNameAndDebug(baseIOdictionary, 0);

    bool baseIOdictionary::writeDictionaries
    (
        debug::infoSwitch("writeDictionaries", 0)
    );
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::baseIOdictionary::baseIOdictionary(const IOobject& io)
:
    regIOobject(io)
{
    dictionary::name() = IOobject::objectPath();
}


Foam::baseIOdictionary::baseIOdictionary
(
    const IOobject& io,
    const dictionary& dict
)
:
    regIOobject(io)
{
    dictionary::name() = IOobject::objectPath();
}


Foam::baseIOdictionary::baseIOdictionary
(
    const IOobject& io,
    Istream& is
)
:
    regIOobject(io)
{
    dictionary::name() = IOobject::objectPath();
}


Foam::baseIOdictionary::baseIOdictionary(const baseIOdictionary& dict)
:
    regIOobject(dict),
    dictionary(dict)
{}


Foam::baseIOdictionary::baseIOdictionary(baseIOdictionary&& dict)
:
    regIOobject(move(dict)),
    dictionary(move(dict))
{}


// * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * * //

Foam::baseIOdictionary::~baseIOdictionary()
{}


// * * * * * * * * * * * * * * * Members Functions * * * * * * * * * * * * * //

const Foam::word& Foam::baseIOdictionary::name() const
{
    return regIOobject::name();
}


// * * * * * * * * * * * * * * * Member Operators  * * * * * * * * * * * * * //

void Foam::baseIOdictionary::operator=(const baseIOdictionary& rhs)
{
    dictionary::operator=(rhs);
}


void Foam::baseIOdictionary::operator=(baseIOdictionary&& rhs)
{
    dictionary::operator=(move(rhs));
}


// ************************************************************************* //
